# GridColumn

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**display_name** | **str** |  | [optional] 
**field_calc_script** | **str** |  | [optional] 
**is_default** | **bool** |  | [optional] 
**is_read_only** | **bool** |  | [optional] 
**key** | **str** |  | [optional] 
**required** | **bool** |  | [optional] 
**script** | **str** |  | [optional] 
**select_values** | **list[str]** |  | [optional] 
**type** | **str** |  | [optional] 
**width** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


